@@ -38,7 +38,8 @@ from swh.deposit.tests.common import (
     post_archive,
     post_atom,
 )
-from swh.model.identifiers import DIRECTORY, REVISION, SNAPSHOT, swhid
+from swh.model.hashutil import hash_to_bytes
+from swh.model.identifiers import CoreSWHID, ObjectType, QualifiedSWHID
 from swh.scheduler import get_scheduler
 
 # mypy is asked to ignore the import statement above because setup_databases
@@ -87,7 +88,9 @@ def deposit_config(swh_scheduler_config, swh_storage_backend_config):
         "extraction_dir": "/tmp/swh-deposit/test/extraction-dir",
         "checks": False,
         "scheduler": {"cls": "local", **swh_scheduler_config,},
+        "storage": swh_storage_backend_config,
         "storage_metadata": swh_storage_backend_config,
+        "swh_authority_url": "http://deposit.softwareheritage.example/",
     }
 
 
@@ -457,18 +460,18 @@ def complete_deposit(sample_archive, deposit_collection, authenticated_client):
     )
     origin = "https://hal.archives-ouvertes.fr/hal-01727745"
     directory_id = "42a13fc721c8716ff695d0d62fc851d641f3a12b"
-    revision_id = "548b3c0a2bb43e1fca191e24b5803ff6b3bc7c10"
-    snapshot_id = "e5e82d064a9c3df7464223042e0c55d72ccff7f0"
-    deposit.swhid = swhid(DIRECTORY, directory_id)
-    deposit.swhid_context = swhid(
-        DIRECTORY,
-        directory_id,
-        metadata={
-            "origin": origin,
-            "visit": swhid(SNAPSHOT, snapshot_id),
-            "anchor": swhid(REVISION, revision_id),
-            "path": "/",
-        },
+    revision_id = hash_to_bytes("548b3c0a2bb43e1fca191e24b5803ff6b3bc7c10")
+    snapshot_id = hash_to_bytes("e5e82d064a9c3df7464223042e0c55d72ccff7f0")
+    deposit.swhid = f"swh:1:dir:{directory_id}"
+    deposit.swhid_context = str(
+        QualifiedSWHID(
+            object_type=ObjectType.DIRECTORY,
+            object_id=hash_to_bytes(directory_id),
+            origin=origin,
+            visit=CoreSWHID(object_type=ObjectType.SNAPSHOT, object_id=snapshot_id),
+            anchor=CoreSWHID(object_type=ObjectType.REVISION, object_id=revision_id),
+            path=b"/",
+        )
     )
     deposit.save()
     return deposit
